searchNodes=[{"ref":"EmailEctoType.html","title":"EmailEctoType","type":"module","doc":"An ecto type that provides easy way of managing email addresses in a database. Usage Suppose you define the following schema defmodule EmailEctoType.Support.Schema do @moduledoc false use Ecto.Schema alias Ecto.Changeset embedded_schema do field :email, EmailEctoType end def changeset(%__MODULE__{} = schema, attrs) do Changeset.cast(schema, attrs, [:email]) end end Now you can validate an email like this: iex(1)&gt; alias EmailEctoType.Support.Schema iex(2)&gt; alias EmailEctoType.Email iex(3)&gt; changeset = Schema.changeset(%Schema{}, %{email: &quot;asdf@host.com&quot;}) iex(4)&gt; changeset.valid? true iex(5)&gt; Ecto.Changeset.apply_changes(changeset) %Schema{email: %Email{address: &quot;asdf@host.com&quot;, user: &quot;asdf&quot;, host: &quot;host.com&quot;}} In case you provide an invalid email it will return an error on casting: iex(1)&gt; alias EmailEctoType.Support.Schema iex(2)&gt; changeset = Schema.changeset(%Schema{}, %{email: &quot;asdf@&quot;}) iex(3)&gt; changeset.valid? false iex(4)&gt; changeset.errors [email: {&quot;is invalid&quot;, [type: EmailEctoType, validation: :cast]}] Custom type You can also define your custom email type using this module: defmodule EmailEctoType.Support.CustomEmailType do @moduledoc false use EmailEctoType, validators: [] end And use it in schema: defmodule EmailEctoType.Support.SchemaWithCustomType do @moduledoc false use Ecto.Schema alias Ecto.Changeset alias EmailEctoType.Support.CustomEmailType embedded_schema do field :email, CustomEmailType end def changeset(%__MODULE__{} = schema, attrs) do Changeset.cast(schema, attrs, [:email]) end end As we did not specify any validators for an email, it won&#39;t fail on invalid strings (see EmailEctoType.Validator for more info): iex(1)&gt; alias EmailEctoType.Support.SchemaWithCustomType, as: Schema iex(2)&gt; changeset = Schema.changeset(%Schema{}, %{email: &quot;asdf@&quot;}) iex(3)&gt; changeset.valid? true"},{"ref":"EmailEctoType.Email.html","title":"EmailEctoType.Email","type":"module","doc":"Type representing an email address."},{"ref":"EmailEctoType.Email.html#new/2","title":"EmailEctoType.Email.new/2","type":"function","doc":""},{"ref":"EmailEctoType.Email.html#t:t/0","title":"EmailEctoType.Email.t/0","type":"type","doc":""},{"ref":"EmailEctoType.FormatValidator.html","title":"EmailEctoType.FormatValidator","type":"module","doc":"Validates an email address against a simple regexp. Used as default validator for EmailEctoType. See EmailEctoType.Validator for details."},{"ref":"EmailEctoType.Validator.html","title":"EmailEctoType.Validator","type":"behaviour","doc":"Behaviour that any validator for EmailEctoType must follow."},{"ref":"EmailEctoType.Validator.html#c:validate/1","title":"EmailEctoType.Validator.validate/1","type":"callback","doc":"Validates if an email satisfies the validator."},{"ref":"readme.html","title":"EmailEctoType","type":"extras","doc":"EmailEctoType An ecto type that provides easy way of managing email addresses in a database."},{"ref":"readme.html#usage","title":"EmailEctoType - Usage","type":"extras","doc":"See hexdocs for details."},{"ref":"readme.html#installation","title":"EmailEctoType - Installation","type":"extras","doc":"The package can be installed by adding email_ecto_type to your list of dependencies in mix.exs: def deps do [ {:email_ecto_type, &quot;~&gt; 0.1.0&quot;} ] end"}]